@@ -11,7 +11,7 @@ use base qw( Tickit IO::Async::Notifier );
 Tickit->VERSION( '0.17' );
 IO::Async::Notifier->VERSION( '0.43' ); # Need support for being a nonprinciple mixin
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use IO::Async::Loop 0.47; # ->run and ->stop methods
 use IO::Async::Signal;
@@ -142,6 +142,12 @@ sub timer
    $self->get_loop->watch_time( $mode => $amount, code => $code );
 }
 
+sub tick
+{
+   my $self = shift;
+   $self->get_loop->loop_once;
+}
+
 sub stop
 {
    my $self = shift;
